"use strict";

require("../../mocha-config");

var MapsAdminPanel = require('../../../../main/js/gui/admin/MapsAdminPanel');
var ServerConnector = require('../../ServerConnector-mock');
var logger = require('../../logger');

var assert = require('assert');

function createMapsAdminPanel() {
  return new MapsAdminPanel({
    element: testDiv,
    configuration: helper.getConfiguration(),
    serverConnector: ServerConnector
  });
}

describe('MapsAdminPanel', function () {

  it('refresh', function () {
    var mapTab = createMapsAdminPanel();
    return mapTab.init().then(function () {
      return mapTab.onRefreshClicked();
    }).then(function () {
      assert.equal(0, logger.getWarnings().length);
      return mapTab.destroy();
    });
  });
  it('showLogs', function () {
    var mapTab = createMapsAdminPanel();
    return mapTab.init().then(function () {
      return mapTab.showLogs("sample", 'error');
    }).then(function () {
      assert.equal(0, logger.getWarnings().length);
      return mapTab.destroy();
    });
  });

  it('getDialog', function () {
    helper.loginAsAdmin();
    var mapTab = createMapsAdminPanel();
    return mapTab.init().then(function () {
      return ServerConnector.getProject();
    }).then(function (project) {
      return mapTab.getDialog(project);
    }).then(function (dialog) {
      assert.ok(dialog.getListeners("onSave").length > 0);
      return mapTab.destroy();
    });
  });


  describe('onAddClicked', function () {
    it('default', function () {
      var mapTab = createMapsAdminPanel();
      return mapTab.init().then(function () {
        return mapTab.onAddClicked();
      }).then(function () {
        return mapTab.destroy();
      });
    });
    it('close and reopen', function () {
      var mapTab = createMapsAdminPanel();
      return mapTab.init().then(function () {
        return mapTab.onAddClicked();
      }).then(function () {
        mapTab._addDialog.close();
        return mapTab.onAddClicked();
      }).then(function () {
        return mapTab.destroy();
      });
    });
  });

  describe('showEditDialog', function () {
    it('default', function () {
      var mapTab = createMapsAdminPanel();
      return mapTab.init().then(function () {
        return mapTab.showEditDialog("sample");
      }).then(function () {
        return mapTab.destroy();
      });
    });
    it('reopen after data changed', function () {
      var mapTab = createMapsAdminPanel();
      var originalFunction = ServerConnector.getProject;
      return mapTab.init().then(function () {
        return mapTab.showEditDialog("sample");
      }).then(function () {
        return ServerConnector.getProject("sample");
      }).then(function (project) {
        project.setName("new name");
        ServerConnector.getProject = function () {
          return Promise.resolve(project);
        };
        return mapTab.showEditDialog("sample");
      }).then(function () {
        var inputs = $('input').filter(function () {
          return this.value === 'new name'
        });
        assert.ok(inputs.length > 0, "Data wasn't updated after reopening popup");
        return mapTab.destroy();
      }).finally(function () {
        ServerConnector.getProject = originalFunction;
      });
    });
  });

});
